<?php

/**
 * Class Settings_Helper
 *
 * This class contains helper methods for retrieving menu item types, share services,
 * and translation options.
 *
 * @package    CounterBox
 * @subpackage Admin
 * @author     Dmytro Lobov <dev@wow-company.com>, Wow-Company
 * @copyright  2024 Dmytro Lobov
 * @license    GPL-2.0+
 */

namespace CounterBox;

defined( 'ABSPATH' ) || exit;

class Settings_Helper {

	public static function languages(): array {
		return [
			'af'             => 'Afrikaans',
			'ar'             => 'العربية',
			'ary'            => 'العربية المغربية',
			'as'             => 'অসমীয়া',
			'az'             => 'Azərbaycan dili',
			'azb'            => 'گؤنئی آذربایجان',
			'bel'            => 'Беларуская мова',
			'bg_BG'          => 'Български',
			'bn_BD'          => 'বাংলা',
			'bo'             => 'བོད་ཡིག',
			'bs_BA'          => 'Bosanski',
			'ca'             => 'Català',
			'ceb'            => 'Cebuano',
			'cs_CZ'          => 'Čeština',
			'cy'             => 'Cymraeg',
			'da_DK'          => 'Dansk',
			'de_DE'          => 'Deutsch',
			'de_CH_informal' => 'Deutsch (Schweiz, Du)',
			'de_CH'          => 'Deutsch (Schweiz)',
			'de_DE_formal'   => 'Deutsch (Sie)',
			'de_AT'          => 'Deutsch (Österreich)',
			'dzo'            => 'རྫོང་ཁ',
			'el'             => 'Ελληνικά',
			'en_US'          => 'English (United States)',
			'en_GB'          => 'English (UK)',
			'en_AU'          => 'English (Australia)',
			'en_NZ'          => 'English (New Zealand)',
			'en_CA'          => 'English (Canada)',
			'en_ZA'          => 'English (South Africa)',
			'eo'             => 'Esperanto',
			'es_ES'          => 'Español',
			'es_VE'          => 'Español de Venezuela',
			'es_GT'          => 'Español de Guatemala',
			'es_CR'          => 'Español de Costa Rica',
			'es_MX'          => 'Español de México',
			'es_CO'          => 'Español de Colombia',
			'es_PE'          => 'Español de Perú',
			'es_CL'          => 'Español de Chile',
			'es_AR'          => 'Español de Argentina',
			'et'             => 'Eesti',
			'eu'             => 'Euskara',
			'fa_IR'          => 'فارسی',
			'fi'             => 'Suomi',
			'fr_FR'          => 'Français',
			'fr_CA'          => 'Français du Canada',
			'fr_BE'          => 'Français de Belgique',
			'fur'            => 'Friulian',
			'gd'             => 'Gàidhlig',
			'gl_ES'          => 'Galego',
			'gu'             => 'ગુજરાતી',
			'haz'            => 'هزاره گی',
			'he_IL'          => 'עִבְרִית',
			'hi_IN'          => 'हिन्दी',
			'hr'             => 'Hrvatski',
			'hu_HU'          => 'Magyar',
			'hy'             => 'Հայերեն',
			'id_ID'          => 'Bahasa Indonesia',
			'is_IS'          => 'Íslenska',
			'it_IT'          => 'Italiano',
			'ja'             => '日本語',
			'jv_ID'          => 'Basa Jawa',
			'ka_GE'          => 'ქართული',
			'kab'            => 'Taqbaylit',
			'kk'             => 'Қазақ тілі',
			'km'             => 'ភាសាខ្មែរ',
			'kn'             => 'ಕನ್ನಡ',
			'ko_KR'          => '한국어',
			'ckb'            => 'كوردی‎',
			'lo'             => 'ພາສາລາວ',
			'lt_LT'          => 'Lietuvių kalba',
			'lv'             => 'Latviešu valoda',
			'mk_MK'          => 'Македонски јазик',
			'ml_IN'          => 'മലയാളം',
			'mn'             => 'Монгол',
			'mr'             => 'मराठी',
			'ms_MY'          => 'Bahasa Melayu',
			'my_MM'          => 'ဗမာစာ',
			'nb_NO'          => 'Norsk bokmål',
			'ne_NP'          => 'नेपाली',
			'nl_NL'          => 'Nederlands',
			'nl_NL_formal'   => 'Nederlands (Formeel)',
			'nl_BE'          => 'Nederlands (België)',
			'nn_NO'          => 'Norsk nynorsk',
			'oci'            => 'Occitan',
			'pa_IN'          => 'ਪੰਜਾਬੀ',
			'pl_PL'          => 'Polski',
			'ps'             => 'پښتو',
			'pt_PT'          => 'Português',
			'pt_AO'          => 'Português de Angola',
			'pt_PT_ao90'     => 'Português (AO90)',
			'pt_BR'          => 'Português do Brasil',
			'rhg'            => 'Ruáinga',
			'ro_RO'          => 'Română',
			'ru_RU'          => 'Русский',
			'sah'            => 'Сахалыы',
			'si_LK'          => 'සිංහල',
			'sk_SK'          => 'Slovenčina',
			'skr'            => 'سرائیکی',
			'sl_SI'          => 'Slovenščina',
			'sq'             => 'Shqip',
			'sr_RS'          => 'Српски језик',
			'sv_SE'          => 'Svenska',
			'szl'            => 'Ślōnskŏ gŏdka',
			'ta_IN'          => 'தமிழ்',
			'te'             => 'తెలుగు',
			'th'             => 'ไทย',
			'tl'             => 'Tagalog',
			'tr_TR'          => 'Türkçe',
			'tt_RU'          => 'Татар теле',
			'tah'            => 'Reo Tahiti',
			'ug_CN'          => 'ئۇيغۇرچە',
			'uk'             => 'Українська',
			'ur'             => 'اردو',
			'uz_UZ'          => 'O‘zbekcha',
			'vi'             => 'Tiếng Việt',
			'zh_CN'          => '简体中文',
			'zh_TW'          => '繁體中文',
			'zh_HK'          => '香港中文版',
			'custom'         => 'Custom'
		];
	}

	public static function animation(): array {
		return [
			'zoomIn'        => 'zoomIn',
			'zoomOut'       => 'zoomOut',
			'slideTop'      => 'slideTop',
			'slideBottom'   => 'slideBottom',
			'slideRight'    => 'slideRight',
			'slideLeft'     => 'slideLeft',
			'slideInTop'    => 'slideInTop',
			'slideInBottom' => 'slideInBottom',
			'slideInRight'  => 'slideInRight',
			'slideInLeft'   => 'slideInLeft',
			'rotateIn'      => 'rotateIn',
			'rotateOut'     => 'rotateOut',
			'flipInX'       => 'flipInX',
			'flipInY'       => 'flipInY',
			'swingTop'      => 'swingTop',
			'swingBottom'   => 'swingBottom',
			'swingRight'    => 'swingRight',
			'swingLeft'     => 'swingLeft',
			'flash'         => 'flash',
			'pulse'         => 'pulse',
			'rubberBand'    => 'rubberBand',
			'shake'         => 'shake',
			'swing'         => 'swing',
			'tada'          => 'tada',
			'wobble'        => 'wobble',
			'bounce'        => 'bounce',
			'bounceIn'      => 'bounceIn',
			'bounceInUp'    => 'bounceInUp',
			'bounceInDown'  => 'bounceInDown',
			'bounceInRight' => 'bounceInRight',
			'bounceInLeft'  => 'bounceInLeft',
			'unFold'        => 'unFold',
			'flowIn'        => 'flowIn',
			'fadeIn'        => 'fadeIn',
		];
	}

	public static function countries(): array {
		return [
			"US"=> "United States",
			"CA"=> "Canada",
			"GB"=> "United Kingdom",
			"AF"=> "Afghanistan",
			"AX"=> "Åland Islands",
			"AL"=> "Albania",
			"DZ"=> "Algeria",
			"AS"=> "American Samoa",
			"AD"=> "Andorra",
			"AO"=> "Angola",
			"AI"=> "Anguilla",
			"AQ"=> "Antarctica",
			"AG"=> "Antigua and Barbuda",
			"AR"=> "Argentina",
			"AM"=> "Armenia",
			"AW"=> "Aruba",
			"AU"=> "Australia",
			"AT"=> "Austria",
			"AZ"=> "Azerbaijan",
			"BS"=> "Bahamas",
			"BH"=> "Bahrain",
			"BD"=> "Bangladesh",
			"BB"=> "Barbados",
			"BY"=> "Belarus",
			"BE"=> "Belgium",
			"BZ"=> "Belize",
			"BJ"=> "Benin",
			"BM"=> "Bermuda",
			"BT"=> "Bhutan",
			"BO"=> "Bolivia",
			"BQ"=> "Bonaire, Saint Eustatius and Saba",
			"BA"=> "Bosnia and Herzegovina",
			"BW"=> "Botswana",
			"BV"=> "Bouvet Island",
			"BR"=> "Brazil",
			"IO"=> "British Indian Ocean Territory",
			"BN"=> "Brunei Darrussalam",
			"BG"=> "Bulgaria",
			"BF"=> "Burkina Faso",
			"BI"=> "Burundi",
			"KH"=> "Cambodia",
			"CM"=> "Cameroon",
			"CV"=> "Cape Verde",
			"KY"=> "Cayman Islands",
			"CF"=> "Central African Republic",
			"TD"=> "Chad",
			"CL"=> "Chile",
			"CN"=> "China",
			"CX"=> "Christmas Island",
			"CC"=> "Cocos Islands",
			"CO"=> "Colombia",
			"KM"=> "Comoros",
			"CD"=> "Congo, Democratic People's Republic",
			"CG"=> "Congo, Republic of",
			"CK"=> "Cook Islands",
			"CR"=> "Costa Rica",
			"CI"=> "Cote d'Ivoire",
			"HR"=> "Croatia/Hrvatska",
			"CU"=> "Cuba",
			"CW"=> "CuraÇao",
			"CY"=> "Cyprus",
			"CZ"=> "Czechia",
			"DK"=> "Denmark",
			"DJ"=> "Djibouti",
			"DM"=> "Dominica",
			"DO"=> "Dominican Republic",
			"TP"=> "East Timor",
			"EC"=> "Ecuador",
			"EG"=> "Egypt",
			"GQ"=> "Equatorial Guinea",
			"SV"=> "El Salvador",
			"ER"=> "Eritrea",
			"EE"=> "Estonia",
			"ET"=> "Ethiopia",
			"FK"=> "Falkland Islands",
			"FO"=> "Faroe Islands",
			"FJ"=> "Fiji",
			"FI"=> "Finland",
			"FR"=> "France",
			"GF"=> "French Guiana",
			"PF"=> "French Polynesia",
			"TF"=> "French Southern Territories",
			"GA"=> "Gabon",
			"GM"=> "Gambia",
			"GE"=> "Georgia",
			"DE"=> "Germany",
			"GR"=> "Greece",
			"GH"=> "Ghana",
			"GI"=> "Gibraltar",
			"GL"=> "Greenland",
			"GD"=> "Grenada",
			"GP"=> "Guadeloupe",
			"GU"=> "Guam",
			"GT"=> "Guatemala",
			"GG"=> "Guernsey",
			"GN"=> "Guinea",
			"GW"=> "Guinea-Bissau",
			"GY"=> "Guyana",
			"HT"=> "Haiti",
			"HM"=> "Heard and McDonald Islands",
			"VA"=> "Holy See (City Vatican State)",
			"HN"=> "Honduras",
			"HK"=> "Hong Kong",
			"HU"=> "Hungary",
			"IS"=> "Iceland",
			"IN"=> "India",
			"ID"=> "Indonesia",
			"IR"=> "Iran",
			"IQ"=> "Iraq",
			"IE"=> "Ireland",
			"IM"=> "Isle of Man",
			"IL"=> "Israel",
			"IT"=> "Italy",
			"JM"=> "Jamaica",
			"JP"=> "Japan",
			"JE"=> "Jersey",
			"JO"=> "Jordan",
			"KZ"=> "Kazakhstan",
			"KE"=> "Kenya",
			"KI"=> "Kiribati",
			"KW"=> "Kuwait",
			"KG"=> "Kyrgyzstan",
			"LA"=> "Lao People's Democratic Republic",
			"LV"=> "Latvia",
			"LB"=> "Lebanon",
			"LS"=> "Lesotho",
			"LR"=> "Liberia",
			"LY"=> "Libyan Arab Jamahiriya",
			"LI"=> "Liechtenstein",
			"LT"=> "Lithuania",
			"LU"=> "Luxembourg",
			"MO"=> "Macau",
			"MK"=> "Macedonia",
			"MG"=> "Madagascar",
			"MW"=> "Malawi",
			"MY"=> "Malaysia",
			"MV"=> "Maldives",
			"ML"=> "Mali",
			"MT"=> "Malta",
			"MH"=> "Marshall Islands",
			"MQ"=> "Martinique",
			"MR"=> "Mauritania",
			"MU"=> "Mauritius",
			"YT"=> "Mayotte",
			"MX"=> "Mexico",
			"FM"=> "Micronesia",
			"MD"=> "Moldova, Republic of",
			"MC"=> "Monaco",
			"MN"=> "Mongolia",
			"ME"=> "Montenegro",
			"MS"=> "Montserrat",
			"MA"=> "Morocco",
			"MZ"=> "Mozambique",
			"MM"=> "Myanmar",
			"NA"=> "Namibia",
			"NR"=> "Nauru",
			"NP"=> "Nepal",
			"NL"=> "Netherlands",
			"AN"=> "Netherlands Antilles",
			"NC"=> "New Caledonia",
			"NZ"=> "New Zealand",
			"NI"=> "Nicaragua",
			"NE"=> "Niger",
			"NG"=> "Nigeria",
			"NU"=> "Niue",
			"NF"=> "Norfolk Island",
			"KP"=> "North Korea",
			"MP"=> "Northern Mariana Islands",
			"NO"=> "Norway",
			"OM"=> "Oman",
			"PK"=> "Pakistan",
			"PW"=> "Palau",
			"PS"=> "Palestinian Territories",
			"PA"=> "Panama",
			"PG"=> "Papua New Guinea",
			"PY"=> "Paraguay",
			"PE"=> "Peru",
			"PH"=> "Philippines",
			"PN"=> "Pitcairn Island",
			"PL"=> "Poland",
			"PT"=> "Portugal",
			"PR"=> "Puerto Rico",
			"QA"=> "Qatar",
			"XK"=> "Republic of Kosovo",
			"RE"=> "Reunion Island",
			"RO"=> "Romania",
			"RU"=> "Russian Federation",
			"RW"=> "Rwanda",
			"BL"=> "Saint Barthélemy",
			"SH"=> "Saint Helena",
			"KN"=> "Saint Kitts and Nevis",
			"LC"=> "Saint Lucia",
			"MF"=> "Saint Martin (French)",
			"SX"=> "Saint Martin (Dutch)",
			"PM"=> "Saint Pierre and Miquelon",
			"VC"=> "Saint Vincent and the Grenadines",
			"SM"=> "San Marino",
			"ST"=> "São Tomé and Príncipe",
			"SA"=> "Saudi Arabia",
			"SN"=> "Senegal",
			"RS"=> "Serbia",
			"SC"=> "Seychelles",
			"SL"=> "Sierra Leone",
			"SG"=> "Singapore",
			"SK"=> "Slovak Republic",
			"SI"=> "Slovenia",
			"SB"=> "Solomon Islands",
			"SO"=> "Somalia",
			"ZA"=> "South Africa",
			"GS"=> "South Georgia",
			"KR"=> "South Korea",
			"SS"=> "South Sudan",
			"ES"=> "Spain",
			"LK"=> "Sri Lanka",
			"SD"=> "Sudan",
			"SR"=> "Suriname",
			"SJ"=> "Svalbard and Jan Mayen Islands",
			"SZ"=> "Swaziland",
			"SE"=> "Sweden",
			"CH"=> "Switzerland",
			"SY"=> "Syrian Arab Republic",
			"TW"=> "Taiwan",
			"TJ"=> "Tajikistan",
			"TZ"=> "Tanzania",
			"TH"=> "Thailand",
			"TL"=> "Timor-Leste",
			"TG"=> "Togo",
			"TK"=> "Tokelau",
			"TO"=> "Tonga",
			"TT"=> "Trinidad and Tobago",
			"TN"=> "Tunisia",
			"TR"=> "Turkey",
			"TM"=> "Turkmenistan",
			"TC"=> "Turks and Caicos Islands",
			"TV"=> "Tuvalu",
			"UG"=> "Uganda",
			"UA"=> "Ukraine",
			"AE"=> "United Arab Emirates",
			"UY"=> "Uruguay",
			"UM"=> "US Minor Outlying Islands",
			"UZ"=> "Uzbekistan",
			"VU"=> "Vanuatu",
			"VE"=> "Venezuela",
			"VN"=> "Vietnam",
			"VG"=> "Virgin Islands (British)",
			"VI"=> "Virgin Islands (USA)",
			"WF"=> "Wallis and Futuna Islands",
			"EH"=> "Western Sahara",
			"WS"=> "Western Samoa",
			"YE"=> "Yemen",
			"ZM"=> "Zambia",
			"ZW"=> "Zimbabwe",
		];

	}

	public static function user_roles(): array {
		$editable_role = array_reverse( get_editable_roles() );
		$users_arr     = array();
		foreach ( $editable_role as $role => $details ) {

			$name = translate_user_role( $details['name'] );
			$val  = [
				'type'  => 'checkbox',
				'title' => $name,
				'label' => __( 'Enable', 'counter-box' ),

			];

			$users_arr[ 'user_' . $role ] = $val;

		}

		return $users_arr;
	}

}
